@@ -17,7 +17,7 @@
 #
 #----------------------------------------------------------------------------
 #
-# $Id: Constants.pm,v 1.11 1999/09/14 23:07:01 abw Exp $
+# $Id: Constants.pm,v 1.13 1999/12/21 14:22:12 abw Exp $
 #
 #============================================================================
  
@@ -30,7 +30,7 @@ use strict;
 use vars qw( $VERSION @ISA @EXPORT_OK %EXPORT_TAGS );
 
 @ISA     = qw( Exporter );
-$VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 # BEGIN { print STDERR "Loading Template::Constants...\n" };
 
@@ -54,6 +54,7 @@ use constant STATUS_ERROR    => 255;      # error condition
 # ERROR constants for indicating soft errors.
 use constant ERROR_FILE      =>  'file';  # file error: I/O, parse, recursion
 use constant ERROR_UNDEF     =>  'undef'; # undefined variable value used
+use constant ERROR_PERL      =>  'perl';  # error in [% PERL %] block
 
 use constant OP_NULLOP       =>   0;      # do nothing
 use constant OP_LITERAL      =>   1;      # literal value, do nothing
@@ -82,11 +83,14 @@ use constant OP_ITERFOLD     =>  22;
 use constant OP_DEFAULT      =>  23;
 use constant OP_ARGS         =>  24;
 use constant OP_RANGEFOLD    =>  25;
+use constant OP_REF          =>  26;
+use constant OP_MAKEREF      =>  27;
 
 use vars qw( @OP_NAME );
 @OP_NAME       = qw( NULLOP LITERAL IDENT RANGE LIST HASH QUOTE UNYOP BINOP 
 		     NOT AND OR DOT LDOT LISTFOLD HASHFOLD HASHKEY LVALUE 
-		     STRCAT ASSIGN LSET ITER ITERFOLD DEFAULT ARGS RFOLD );
+		     STRCAT ASSIGN LSET ITER ITERFOLD DEFAULT ARGS RFOLD 
+		     REF MAKEREF );
 
 # CACHE constants controlling the Template::Cache
 use constant CACHE_NONE      =>   0;	  # don't cache anything
@@ -106,13 +110,14 @@ use constant DEBUG_ALL       => DEBUG_INFO | DEBUG_DATA | DEBUG_TOKEN |
 my @TEMPLATE = qw( TEMPLATE_OUTPUT TEMPLATE_ERROR TEMPLATE_DEBUG );
 my @STATUS   = qw( STATUS_OK STATUS_RETURN STATUS_STOP STATUS_DONE
 		   STATUS_ERROR );
-my @ERROR    = qw( ERROR_FILE ERROR_UNDEF );
+my @ERROR    = qw( ERROR_FILE ERROR_UNDEF ERROR_PERL );
 
 my @OPS      = qw( OP_NULLOP OP_LITERAL OP_IDENT OP_RANGE OP_LIST OP_HASH 
 		   OP_QUOTE OP_UNYOP OP_BINOP OP_NOT OP_AND OP_OR OP_DOT
 		   OP_LDOT OP_LISTFOLD OP_HASHFOLD OP_HASHKEY OP_LVALUE 
 		   OP_STRCAT OP_ASSIGN OP_LSET OP_ITER OP_ITERFOLD 
-		   OP_DEFAULT OP_ARGS OP_RANGEFOLD @OP_NAME );
+		   OP_DEFAULT OP_ARGS OP_RANGEFOLD OP_REF OP_MAKEREF 
+		   @OP_NAME );
 my @CACHE    = qw( CACHE_NONE CACHE_ALL );
 my @DEBUG    = qw( DEBUG_NONE DEBUG_INFO DEBUG_DATA DEBUG_TOKEN 
                    DEBUG_PARSE DEBUG_PROCESS DEBUG_ALL );
@@ -215,7 +220,7 @@ Andy Wardley E<lt>abw@cre.canon.co.ukE<gt>
 
 =head1 REVISION
 
-$Revision: 1.11 $
+$Revision: 1.13 $
 
 =head1 COPYRIGHT
 
